@@ -1,6 +1,6 @@
 /* idn.c --- Command line interface to libidn.
- * Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Simon
- * Josefsson
+ * Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
+ * Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -28,6 +28,7 @@
 #include <string.h>
 #include <errno.h>
 #include <locale.h>
+#include <unistd.h>
 
 /* Gnulib headers. */
 #include "error.h"
@@ -175,13 +176,17 @@ main (int argc, char *argv[])
       usage (EXIT_FAILURE);
     }
 
-  if (!args_info.quiet_given)
+  if (!args_info.quiet_given
+      && args_info.inputs_num == 0
+      && isatty (fileno (stdin)))
     fprintf (stderr, "%s %s\n" GREETING, PACKAGE, VERSION);
 
   if (args_info.debug_given)
     fprintf (stderr, _("Charset `%s'.\n"), stringprep_locale_charset ());
 
-  if (!args_info.quiet_given && args_info.inputs_num == 0)
+  if (!args_info.quiet_given
+      && args_info.inputs_num == 0
+      && isatty (fileno (stdin)))
     fprintf (stderr, _("Type each input string on a line by itself, "
 		       "terminated by a newline character.\n"));
 
