@@ -469,7 +469,7 @@ doit (void)
   for (i = 0; i < sizeof (idna) / sizeof (idna[0]); i++)
     {
       if (debug)
-	printf ("IDNA2 entry %d\n", i);
+	printf ("IDNA2 entry %ld\n", i);
 
       if (debug)
 	{
@@ -488,7 +488,7 @@ doit (void)
 			     IDNA_USE_STD3_ASCII_RULES);
       if (rc != IDNA_SUCCESS && strlen (idna[i].out) > 0)
 	{
-	  fail ("IDNA2 entry %d failed: %d\n", i, rc);
+	  fail ("IDNA2 entry %ld failed: %d\n", i, rc);
 	  continue;
 	}
 
@@ -505,7 +505,7 @@ doit (void)
 	  if (strlen (idna[i].out) != strlen (out) ||
 	      strcasecmp (idna[i].out, out) != 0)
 	    {
-	      fail ("IDNA2 entry %d failed\n", i);
+	      fail ("IDNA2 entry %ld failed\n", i);
 	      if (debug)
 		printf ("ERROR\n");
 	    }
