@@ -74,13 +74,13 @@ doit (void)
   for (i = 0; i < sizeof (nfkc) / sizeof (nfkc[0]); i++)
     {
       if (debug)
-	printf ("NFKC entry %d\n", i);
+	printf ("NFKC entry %ld\n", i);
 
       out = stringprep_utf8_nfkc_normalize (nfkc[i].in,
 					    (ssize_t) strlen (nfkc[i].in));
       if (out == NULL)
 	{
-	  fail ("NFKC entry %d failed fatally\n", i);
+	  fail ("NFKC entry %ld failed fatally\n", i);
 	  continue;
 	}
 
@@ -115,7 +115,7 @@ doit (void)
       if (strlen (nfkc[i].out) != strlen (out) ||
 	  memcmp (nfkc[i].out, out, strlen (out)) != 0)
 	{
-	  fail ("NFKC entry %d failed\n", i);
+	  fail ("NFKC entry %ld failed\n", i);
 	  if (debug)
 	    printf ("ERROR\n");
 	}
