@@ -187,7 +187,7 @@ doit (void)
   for (i = 0; i < sizeof (punycode) / sizeof (punycode[0]); i++)
     {
       if (debug)
-	printf ("PUNYCODE entry %d: %s\n", i, punycode[i].name);
+	printf ("PUNYCODE entry %ld: %s\n", i, punycode[i].name);
 
       if (debug)
 	{
@@ -200,7 +200,7 @@ doit (void)
 			    NULL, &outlen, p);
       if (rc != punycode[i].rc)
 	{
-	  fail ("punycode_encode() entry %d failed: %d\n", i, rc);
+	  fail ("punycode_encode() entry %ld failed: %d\n", i, rc);
 	  if (debug)
 	    printf ("FATAL\n");
 	  continue;
@@ -222,7 +222,7 @@ doit (void)
 	  if (strlen (punycode[i].out) != strlen (p) ||
 	      memcmp (punycode[i].out, p, strlen (p)) != 0)
 	    {
-	      fail ("punycode() entry %d failed\n", i);
+	      fail ("punycode() entry %ld failed\n", i);
 	      if (debug)
 		printf ("ERROR\n");
 	    }
@@ -242,7 +242,7 @@ doit (void)
 			    &outlen, q, NULL);
       if (rc != punycode[i].rc)
 	{
-	  fail ("punycode() entry %d failed: %d\n", i, rc);
+	  fail ("punycode() entry %ld failed: %d\n", i, rc);
 	  if (debug)
 	    printf ("FATAL\n");
 	  continue;
@@ -263,7 +263,7 @@ doit (void)
 	  if (punycode[i].inlen != outlen ||
 	      memcmp (punycode[i].in, q, outlen) != 0)
 	    {
-	      fail ("punycode_decode() entry %d failed\n", i);
+	      fail ("punycode_decode() entry %ld failed\n", i);
 	      if (debug)
 		printf ("ERROR\n");
 	    }
