@@ -219,7 +219,7 @@ doit (void)
   for (i = 0; i < sizeof (strprep) / sizeof (strprep[0]); i++)
     {
       if (debug)
-	printf ("STRINGPREP entry %d\n", i);
+	printf ("STRINGPREP entry %ld\n", i);
 
       if (debug)
 	{
@@ -240,7 +240,7 @@ doit (void)
 
 	if (strcmp (strprep[i].in, x) != 0)
 	  {
-	    fail ("bad UTF-8 in entry %d\n", i);
+	    fail ("bad UTF-8 in entry %ld\n", i);
 	    if (debug)
 	      {
 		puts ("expected:");
@@ -260,7 +260,7 @@ doit (void)
 			       "Nameprep", strprep[i].flags);
       if (rc != strprep[i].rc)
 	{
-	  fail ("stringprep() entry %d failed: %d\n", i, rc);
+	  fail ("stringprep() entry %ld failed: %d\n", i, rc);
 	  if (debug)
 	    printf ("FATAL\n");
 	  if (rc == STRINGPREP_OK)
@@ -288,7 +288,7 @@ doit (void)
 	  if (strlen (strprep[i].out) != strlen (p) ||
 	      memcmp (strprep[i].out, p, strlen (p)) != 0)
 	    {
-	      fail ("stringprep() entry %d failed\n", i);
+	      fail ("stringprep() entry %ld failed\n", i);
 	      if (debug)
 		printf ("ERROR\n");
 	    }
